@@ -145,7 +145,7 @@ iBaseType_Cvt(PyObject *object,int *val)
     int tmp = PyInt_AsLong(object);
     if(PyErr_Occurred())
         return 0;
-    if(tmp < iBase_VERTEX || tmp > iBase_ALL_TYPES)
+    if(tmp < iBase_EntityType_MIN || tmp > iBase_EntityType_MAX)
     {
         PyErr_SetString(PyExc_ValueError,ERR_INVALID_TYPE);
         return 0;
@@ -161,7 +161,7 @@ iBaseStorageOrder_Cvt(PyObject *object,int *val)
     int tmp = PyInt_AsLong(object);
     if(PyErr_Occurred())
         return 0;
-    if(tmp < iBase_BLOCKED || tmp > iBase_INTERLEAVED)
+    if(tmp < iBase_StorageOrder_MIN || tmp > iBase_StorageOrder_MAX)
     {
         PyErr_SetString(PyExc_ValueError,ERR_INVALID_STG);
         return 0;
@@ -279,7 +279,6 @@ PyMODINIT_FUNC initiBase(void)
 
     const char *exc_names[] = {
         "MeshAlreadyLoadedError",
-        "NoMeshDataError",
         "FileNotFoundError",
         "FileWriteError",
         "NilArrayError",
