@@ -13,6 +13,7 @@ typedef struct
 {
     PyObject_HEAD
     iGeom_Instance handle;
+    int owned;
 } iGeom_Object;
 
 #define iGeom_Check(o)                                 \
@@ -25,8 +26,8 @@ typedef struct
     int is_arr;
     union
     {
-        iGeom_EntityIterator    one;
-        iGeom_EntityArrIterator arr;
+        iBase_EntityIterator    one;
+        iBase_EntityArrIterator arr;
     } iter;
 } iGeomIter_Object;
 
@@ -36,13 +37,13 @@ typedef struct
     iGeom_Object *instance;
 } iGeomEntitySet_Object;
 
-#define iGeomEntitySet_NewRaw()                         \
-    PyObject_New(iGeomEntitySet_Object,&iGeomEntitySet_Type)
+#define iGeomEntitySet_New()                            \
+    PyObject_AllocNew(iGeomEntitySet_Object,&iGeomEntitySet_Type)
 
 #define iGeomEntitySet_Check(o)                         \
     PyObject_TypeCheck((PyObject*)(o),&iGeomEntitySet_Type)
 
-#define iGeomEntitySet_GetInstance(o)                   \
+#define iGeomEntitySet_GET_INSTANCE(o)                  \
     ( ((iGeomEntitySet_Object*)(o))->instance )
 
 typedef struct
@@ -51,13 +52,13 @@ typedef struct
     iGeom_Object *instance;
 } iGeomTag_Object;
 
-#define iGeomTag_NewRaw()                               \
-        PyObject_New(iGeomTag_Object,&iGeomTag_Type)
+#define iGeomTag_New()                                  \
+    PyObject_AllocNew(iGeomTag_Object,&iGeomTag_Type)
 
 #define iGeomTag_Check(o)                               \
     PyObject_TypeCheck((PyObject*)(o),&iGeomTag_Type)
 
-#define iGeomTag_GetInstance(o)                         \
+#define iGeomTag_GET_INSTANCE(o)                        \
     ( ((iGeomTag_Object*)(o))->instance )
 
 enum iGeomExt_Basis
@@ -67,6 +68,10 @@ enum iGeomExt_Basis
     iGeomExt_U
 };
 
+typedef PyObject * (*geomfrominstfunc)(iGeom_Instance);
+typedef PyObject * (*geomfromsetfunc)(iGeom_Object *,iBase_EntitySetHandle);
+typedef PyObject * (*geomfromtagfunc)(iGeom_Object *,iBase_TagHandle);
+typedef iGeom_Object * (*geomgetinstfunc)(PyObject *o);
 
 #ifndef _IGEOM_MODULE
 
@@ -82,24 +87,23 @@ void **IGeom_API;
 static void **IGeom_API = NULL;
 #endif
 
-#define iGeom_Type          (*(PyTypeObject*)    IGeom_API[ 0])
-#define iGeomIter_Type      (*(PyTypeObject*)    IGeom_API[ 1])
-#define iGeomEntitySet_Type (*(PyTypeObject*)    IGeom_API[ 2])
-#define iGeomTag_Type       (*(PyTypeObject*)    IGeom_API[ 3])
-#define NPY_IGEOMENTSET     (*(int*)             IGeom_API[ 4])
-#define NPY_IGEOMTAG        (*(int*)             IGeom_API[ 5])
-#define iGeomEntitySet_New  ( (iGeomEntitySet_Object * (*)      \
-                              (iGeom_Object *))  IGeom_API[ 6])
-#define iGeomTag_New        ( (iGeomTag_Object * (*)            \
-                              (iGeom_Object *))  IGeom_API[ 7])
-#define NormalPl_Type       (*(PyTypeObject*)    IGeom_API[ 8])
-#define FaceEval_Type       (*(PyTypeObject*)    IGeom_API[ 9])
-#define EdgeEval_Type       (*(PyTypeObject*)    IGeom_API[10])
-#define Deriv1st_Type       (*(PyTypeObject*)    IGeom_API[11])
-#define Deriv2nd_Type       (*(PyTypeObject*)    IGeom_API[12])
-#define Intersect_Type      (*(PyTypeObject*)    IGeom_API[13])
-#define Tolerance_Type      (*(PyTypeObject*)    IGeom_API[14])
-#define iGeomBasis_Cvt      ( (cvtfunc)          IGeom_API[15])
+#define iGeom_Type                 (*(PyTypeObject*)   IGeom_API[ 0])
+#define iGeomIter_Type             (*(PyTypeObject*)   IGeom_API[ 1])
+#define iGeomEntitySet_Type        (*(PyTypeObject*)   IGeom_API[ 2])
+#define iGeomTag_Type              (*(PyTypeObject*)   IGeom_API[ 3])
+#define iGeom_FromInstance         ( (geomfrominstfunc)IGeom_API[ 4])
+#define iGeomEntitySet_FromHandle  ( (geomfromsetfunc) IGeom_API[ 5])
+#define iGeomEntitySet_GetInstance ( (geomgetinstfunc) IGeom_API[ 6])
+#define iGeomTag_FromHandle        ( (geomfromtagfunc) IGeom_API[ 7])
+#define iGeomTag_GetInstance       ( (geomgetinstfunc) IGeom_API[ 8])
+#define NormalPl_Type              (*(PyTypeObject*)   IGeom_API[ 9])
+#define FaceEval_Type              (*(PyTypeObject*)   IGeom_API[10])
+#define EdgeEval_Type              (*(PyTypeObject*)   IGeom_API[11])
+#define Deriv1st_Type              (*(PyTypeObject*)   IGeom_API[12])
+#define Deriv2nd_Type              (*(PyTypeObject*)   IGeom_API[13])
+#define Intersect_Type             (*(PyTypeObject*)   IGeom_API[14])
+#define Tolerance_Type             (*(PyTypeObject*)   IGeom_API[15])
+#define iGeomBasis_Cvt             ( (cvtfunc)         IGeom_API[16])
 
 
 #if !defined(NO_IMPORT_IGEOM) && !defined(NO_IMPORT)
