@@ -39,11 +39,7 @@ checkError(iMesh_Instance mesh,int err)
     if(err)
     {
         char descr[120];
-        int descr_err;
-        iMesh_getDescription(mesh,descr,&descr_err,sizeof(descr)-1);
-        if(descr_err)
-            strncpy(descr,"Unable to retrieve error description",sizeof(descr));
-
+        iMesh_getDescription(mesh,descr,sizeof(descr)-1);
         PyErr_SetString(PyExc_Errors[err-1],descr);
         return 1;
     }
@@ -57,7 +53,7 @@ iMeshTopology_Cvt(PyObject *object,int *val)
     int tmp = PyInt_AsLong(object);
     if(PyErr_Occurred())
         return 0;
-    if(tmp < iMesh_POINT || tmp > iMesh_ALL_TOPOLOGIES)
+    if(tmp < iMesh_EntityTopology_MIN || tmp > iMesh_EntityTopology_MAX)
     {
         PyErr_SetString(PyExc_ValueError,ERR_INVALID_TOPO);
         return 0;
