@@ -11,6 +11,7 @@
 
 static PyTypeObject iRel_Type;
 static PyTypeObject iRelPair_Type;
+static PyTypeObject iRelPairSide_Type;
 
 /* automatic method/property declarators */
 #define IREL_METHOD(cls, name, type)                     \
@@ -33,11 +34,7 @@ checkError(iRel_Instance rel,int err)
     if(err)
     {
         char descr[120];
-        int descr_err;
-        iRel_getDescription(rel,descr,&descr_err,sizeof(descr)-1);
-        if(descr_err)
-            strncpy(descr,"Unable to retrieve error description",sizeof(descr));
-
+        iRel_getDescription(rel,descr,sizeof(descr)-1);
         PyErr_SetString(PyExc_Errors[err-1],descr);
         return 1;
     }
@@ -51,7 +48,7 @@ iRelType_Cvt(PyObject *object,int *val)
     int tmp = PyInt_AsLong(object);
     if(PyErr_Occurred())
         return 0;
-    if(tmp < iRel_ENTITY || tmp > iRel_BOTH)
+    if(tmp < iRel_RelationType_MIN || tmp > iRel_RelationType_MAX)
     {
         PyErr_SetString(PyExc_ValueError,ERR_INVALID_RELTYPE);
         return 0;
@@ -61,6 +58,22 @@ iRelType_Cvt(PyObject *object,int *val)
     return 1;
 }
 
+static int
+iRelStatus_Cvt(PyObject *object,int *val)
+{
+    int tmp = PyInt_AsLong(object);
+    if(PyErr_Occurred())
+        return 0;
+    if(tmp < iRel_RelationStatus_MIN || tmp > iRel_RelationStatus_MAX)
+    {
+        PyErr_SetString(PyExc_ValueError,ERR_INVALID_RELSTATUS);
+        return 0;
+    }
+
+    *val = tmp;
+    return 1;
+}
+
 static int
 get_iface_type(iBase_Object *o)
 {
@@ -93,10 +106,33 @@ static iRelPair_Object *
 iRelPair_FromInstance(iRel_Object *instance)
 {
     iRelPair_Object *o = iRelPair_New();
+    if(o == NULL)
+        return NULL;
+
     o->instance = instance;
     o->handle = NULL;
     Py_INCREF(o->instance);
+
+    o->sides[0] = NULL;
+    o->sides[1] = NULL;
+
+    int i;
+    for(i=0; i<2; i++)
+    {
+        o->sides[i] = iRelPairSide_New();
+        if(o == NULL)
+            goto err;
+        o->sides[i]->parent = o;
+        o->sides[i]->side = i;
+        Py_INCREF(o);
+    }
+
     return o;
+err:
+    Py_XDECREF(o->sides[0]);
+    Py_XDECREF(o->sides[1]);
+    Py_DECREF(o);
+    return NULL;
 }
 
 static PyObject *
@@ -125,11 +161,11 @@ iRelObj_init(iRel_Object *self,PyObject *args,PyObject *kw)
        if necessary */
     if(self->handle && self->owned)
     {
-        iRel_dtor(self->handle,&err);
+        iRel_destroy(self->handle,&err);
         if(checkError(self->handle,err))
             return -1;
     }
-    iRel_newRel(options,&self->handle,&err,strlen(options));
+    iRel_create(options,&self->handle,&err,strlen(options));
     if(checkError(self->handle,err))
         return -1;
     self->owned = 1;
@@ -142,7 +178,7 @@ iRelObj_dealloc(iRel_Object *self)
     if(self->handle && self->owned)
     {
         int err;
-        iRel_dtor(self->handle,&err);
+        iRel_destroy(self->handle,&err);
     }
     self->ob_type->tp_free((PyObject*)self);
 }
@@ -150,21 +186,38 @@ iRelObj_dealloc(iRel_Object *self)
 static PyObject *
 iRelObj_createPair(iRel_Object *self,PyObject *args,PyObject *kw)
 {
-    static char *kwlist[] = {"first","first_type","second","second_type",0};
+    static char *kwlist1[] = {"left", "left_type",
+                              "right","right_type",0};
+    static char *kwlist2[] = {"left", "left_type", "left_status",
+                              "right","right_type","right_status",0};
+
     int err;
     iBase_Object *iface1;
     int ent_or_set1;
+    int status1 = iRel_ACTIVE;
     iBase_Object *iface2;
     int ent_or_set2;
+    int status2 = iRel_ACTIVE;
 
     int type1,type2;
 
-    if(!PyArg_ParseTupleAndKeywords(args,kw,"O!O&O!O&",kwlist,
+    /* first, try the brief signature (no status args) */
+    if(!PyArg_ParseTupleAndKeywords(args,kw,"O!O&O!O&",kwlist1,
                                     &iBase_Type, &iface1,
                                     iRelType_Cvt,&ent_or_set1,
                                     &iBase_Type, &iface2,
-                                    iRelType_Cvt,&ent_or_set2))
-        return NULL;
+                                    iRelType_Cvt,&ent_or_set2)) {
+        PyErr_Clear();
+        /* now, try the full signature (with status args) */
+        if(!PyArg_ParseTupleAndKeywords(args,kw,"O!O&O&O!O&O&",kwlist2,
+                                        &iBase_Type, &iface1,
+                                        iRelType_Cvt,&ent_or_set1,
+                                        iRelStatus_Cvt,&status1,
+                                        &iBase_Type, &iface2,
+                                        iRelType_Cvt,&ent_or_set2,
+                                        iRelStatus_Cvt,&status2))
+            return NULL;
+    }
 
     type1 = get_iface_type(iface1);
     type2 = get_iface_type(iface2);
@@ -176,8 +229,10 @@ iRelObj_createPair(iRel_Object *self,PyObject *args,PyObject *kw)
 
     iRelPair_Object *pair = iRelPair_FromInstance(self);
 
-    iRel_createPair(self->handle,iface1->handle,ent_or_set1,type1,
-                    iface2->handle,ent_or_set2,type2,&pair->handle,&err);
+    iRel_createPair(self->handle,
+                    iface1->handle,ent_or_set1,type1,status1,
+                    iface2->handle,ent_or_set2,type2,status2,
+                    &pair->handle,&err);
     if(checkError(self->handle,err))
         return NULL;
 
@@ -236,11 +291,12 @@ iRelObj_findPairs(iRel_Object *self,PyObject *args,PyObject *kw)
         iBase_Instance iface[2];
         int ent_or_set[2];
         int type[2];
+        int status[2];
 
         pair->handle = pairs[i];
         iRel_getPairInfo(self->handle,pairs[i],
-                         iface+0,ent_or_set+0,type+0,
-                         iface+1,ent_or_set+1,type+1,&err);
+                         iface+0,ent_or_set+0,type+0,status+0,
+                         iface+1,ent_or_set+1,type+1,status+1,&err);
 
         pair->related[0] = (iBase_Object*)iBase_FromInstance(iface[0],type[0]);
         pair->related[1] = (iBase_Object*)iBase_FromInstance(iface[0],type[1]);
@@ -341,6 +397,7 @@ static PyMethodDef module_methods[] = {
 };
 
 ENUM_TYPE(iRelType,"iRel.Type","");
+ENUM_TYPE(iRelStatus,"iRel.Status","");
 
 PyMODINIT_FUNC initiRel(void)
 {
@@ -357,6 +414,7 @@ PyMODINIT_FUNC initiRel(void)
     static void *IRel_API[] = {
          &iRel_Type,
          &iRelPair_Type,
+         &iRelPairSide_Type,
          &iRel_FromInstance,
     };
     PyObject *api_obj;
@@ -367,8 +425,9 @@ PyMODINIT_FUNC initiRel(void)
     if(api_obj != NULL)
         PyModule_AddObject(m, "_C_API", api_obj);
 
-    REGISTER_CLASS(m,"Rel", iRel);
-    REGISTER_CLASS(m,"Pair",iRelPair);
+    REGISTER_CLASS(m,"Rel",      iRel);
+    REGISTER_CLASS(m,"Pair",     iRelPair);
+    REGISTER_CLASS(m,"PairSide", iRelPairSide);
 
     /***** initialize relation type enum *****/
     REGISTER_CLASS(m,"Type",iRelType);
@@ -377,9 +436,17 @@ PyMODINIT_FUNC initiRel(void)
     ADD_ENUM(iRelType,"set",    iRel_SET);
     ADD_ENUM(iRelType,"both",   iRel_BOTH);
 
+    /***** initialize relation status enum *****/
+    REGISTER_CLASS(m,"Status",iRelStatus);
+
+    ADD_ENUM(iRelStatus,"active",    iRel_ACTIVE);
+    ADD_ENUM(iRelStatus,"inactive",  iRel_INACTIVE);
+    ADD_ENUM(iRelStatus,"not_exist", iRel_NOTEXIST);
+
     /* eliminate warnings */
     (void)PyArray_ToVectors;
 }
 
 /* Include source files so that everything is in one translation unit */
+#include "iRel_pairSide.inl"
 #include "iRel_pair.inl"
