@@ -13,17 +13,17 @@ class TestIndexedList(unittest.TestCase):
 
     def testBasic(self):
         self.assertEqual(len(self.list), 4)
-        self.assert_((self.list[0] == range(10, 13)).all())
+        self.assertArray(self.list[0], range(10, 13))
 
-        self.assert_((self.list.indices.offsets == range(0, 13, 3)).all())
-        self.assert_((self.list.indices.data == self.indices).all())
-        self.assert_((self.list.data == range(10, 16)).all())
+        self.assertArray(self.list.indices.offsets, range(0, 13, 3))
+        self.assertArray(self.list.indices.data, self.indices)
+        self.assertArray(self.list.data, range(10, 16))
 
     def testIndex(self):
         for i, hunk in enumerate(self.list):
             self.assertEqual(len(hunk), 3)
             self.assertEqual(self.list.length(i), 3)
-            self.assert_((hunk == range(i+10, i+13)).all())
+            self.assertArray(hunk, range(i+10, i+13))
 
             for j, val in enumerate(hunk):
                 self.assertEqual(val, i+j+10)
