@@ -16,8 +16,8 @@ class TestCreation(unittest.TestCase):
         ent = self.geom.createSphere(1)
 
         lo, hi = self.geom.getEntBoundBox(ent)
-        self.assert_((lo == [-1,-1,-1]).all())
-        self.assert_((hi == [ 1, 1, 1]).all())
+        self.assertArray(lo, [-1,-1,-1])
+        self.assertArray(hi, [ 1, 1, 1])
 
     def testPrism(self):
         ent = self.geom.createPrism(2, 3, 4, 4)
@@ -26,67 +26,67 @@ class TestCreation(unittest.TestCase):
         ent = self.geom.createBrick(2, 2, 2)
 
         lo, hi = self.geom.getEntBoundBox(ent)
-        self.assert_((lo == [-1,-1,-1]).all())
-        self.assert_((hi == [ 1, 1, 1]).all())
+        self.assertArray(lo, [-1,-1,-1])
+        self.assertArray(hi, [ 1, 1, 1])
 
         # alternate form
         ent = self.geom.createBrick([2, 2, 2])
 
         lo, hi = self.geom.getEntBoundBox(ent)
-        self.assert_((lo == [-1,-1,-1]).all())
-        self.assert_((hi == [ 1, 1, 1]).all())
+        self.assertArray(lo, [-1,-1,-1])
+        self.assertArray(hi, [ 1, 1, 1])
 
     def testCylinder(self):
         ent = self.geom.createCylinder(2, 1, 1)
         lo, hi = self.geom.getEntBoundBox(ent)
-        self.assert_((lo == [-1,-1,-1]).all())
-        self.assert_((hi == [ 1, 1, 1]).all())
+        self.assertArray(lo, [-1,-1,-1])
+        self.assertArray(hi, [ 1, 1, 1])
 
     def testCone(self):
         ent = self.geom.createCone(2, 1, 1, 0.5)
 
         lo, hi = self.geom.getEntBoundBox(ent)
-        self.assert_((lo == [-1,-1,-1]).all())
-        self.assert_((hi == [ 1, 1, 1]).all())
+        self.assertArray(lo, [-1,-1,-1])
+        self.assertArray(hi, [ 1, 1, 1])
 
     def testTorus(self):
         ent = self.geom.createTorus(2, 1)
 
         lo, hi = self.geom.getEntBoundBox(ent)
-        self.assert_((lo == [-3,-3,-1]).all())
-        self.assert_((hi == [ 3, 3, 1]).all())
+        self.assertArray(lo, [-3,-3,-1])
+        self.assertArray(hi, [ 3, 3, 1])
 
     def testMove(self):
         ent = self.geom.createBrick(2, 2, 2)
         self.geom.moveEnt(ent, [1,0,0])
 
         lo, hi = self.geom.getEntBoundBox(ent)
-        self.assert_((lo == [ 0,-1,-1]).all())
-        self.assert_((hi == [ 2, 1, 1]).all())
+        self.assertArray(lo, [ 0,-1,-1])
+        self.assertArray(hi, [ 2, 1, 1])
 
     def testScale(self):
         ent = self.geom.createBrick(2, 2, 2)
         self.geom.scaleEnt(ent, [1,2,3])
 
         lo, hi = self.geom.getEntBoundBox(ent)
-        self.assert_((lo == [-1,-2,-3]).all())
-        self.assert_((hi == [ 1, 2, 3]).all())
+        self.assertArray(lo, [-1,-2,-3])
+        self.assertArray(hi, [ 1, 2, 3])
 
     def testReflect(self):
         ent = self.geom.createBrick(2, 4, 6)
         self.geom.reflectEnt(ent, [1,1,0])
 
         lo, hi = self.geom.getEntBoundBox(ent)
-        self.assert_((abs(lo - [-2,-1,-3]) < 1e-5).all())
-        self.assert_((abs(hi - [ 2, 1, 3]) < 1e-5).all())
+        self.assertTrue((abs(lo - [-2,-1,-3]) < 1e-5).all())
+        self.assertTrue((abs(hi - [ 2, 1, 3]) < 1e-5).all())
 
     def testRotate(self):
         ent = self.geom.createBrick(2, 4, 6)
         self.geom.rotateEnt(ent, 90, [1,0,0])
 
         lo, hi = self.geom.getEntBoundBox(ent)
-        self.assert_((lo == [-1,-3,-2]).all())
-        self.assert_((hi == [ 1, 3, 2]).all())
+        self.assertArray(lo, [-1,-3,-2])
+        self.assertArray(hi, [ 1, 3, 2])
 
     def testSweep(self):
         ent = self.geom.createBrick(2, 2, 2)
@@ -96,8 +96,8 @@ class TestCreation(unittest.TestCase):
         axis = self.geom.getEntTangent(edge, [0,0,0])
         result = self.geom.sweepEntAboutAxis(edge, 360, axis)
         lo, hi = self.geom.getEntBoundBox(result)
-        self.assert_((abs(lo - [-sqrt(2),-1,-sqrt(2)]) < 1e-5).all())
-        self.assert_((abs(hi - [ sqrt(2), 1, sqrt(2)]) < 1e-5).all())
+        self.assertTrue((abs(lo - [-sqrt(2),-1,-sqrt(2)]) < 1e-5).all())
+        self.assertTrue((abs(hi - [ sqrt(2), 1, sqrt(2)]) < 1e-5).all())
 
     def testSection(self):
         ent = self.geom.createSphere(1)
@@ -145,8 +145,8 @@ class TestCreation(unittest.TestCase):
         ent2 = self.geom.copyEnt(ent1)
 
         self.assertEqual(self.geom.getNumOfType(iBase.Type.region), 2)
-        self.assert_((numpy.array(self.geom.getEntBoundBox(ent1)) ==
-                      numpy.array(self.geom.getEntBoundBox(ent2))).all())
+        self.assertArray(numpy.array(self.geom.getEntBoundBox(ent1)),
+                         numpy.array(self.geom.getEntBoundBox(ent2)))
 
     def testUnite(self):
         ent1 = self.geom.createBrick(2, 2, 4)
@@ -155,8 +155,8 @@ class TestCreation(unittest.TestCase):
         union = self.geom.uniteEnts([ent1, ent2, ent3])
 
         lo, hi = self.geom.getEntBoundBox(union)
-        self.assert_((lo == [-2,-2,-2]).all())
-        self.assert_((hi == [ 2, 2, 2]).all())
+        self.assertArray(lo, [-2,-2,-2])
+        self.assertArray(hi, [ 2, 2, 2])
 
         # alternate syntax
         ent1 = self.geom.createBrick(2, 2, 4)
@@ -165,8 +165,8 @@ class TestCreation(unittest.TestCase):
         union = self.geom.uniteEnts(ent1, ent2, ent3)
 
         lo, hi = self.geom.getEntBoundBox(union)
-        self.assert_((lo == [-2,-2,-2]).all())
-        self.assert_((hi == [ 2, 2, 2]).all())
+        self.assertArray(lo, [-2,-2,-2])
+        self.assertArray(hi, [ 2, 2, 2])
 
     def testIntersection(self):
         ent1 = self.geom.createBrick(2, 2, 4)
@@ -174,8 +174,8 @@ class TestCreation(unittest.TestCase):
         isect = self.geom.intersectEnts(ent1, ent2)
 
         lo, hi = self.geom.getEntBoundBox(isect)
-        self.assert_((lo == [-1,-1,-1]).all())
-        self.assert_((hi == [ 1, 1, 1]).all())
+        self.assertArray(lo, [-1,-1,-1])
+        self.assertArray(hi, [ 1, 1, 1])
 
     def testSubtract(self):
         ent1 = self.geom.createBrick(4, 4, 4)
@@ -184,5 +184,5 @@ class TestCreation(unittest.TestCase):
         sub = self.geom.subtractEnts(ent1, ent2)
 
         lo, hi = self.geom.getEntBoundBox(sub)
-        self.assert_((lo == [-2,-2,-2]).all())
-        self.assert_((hi == [ 0, 2, 2]).all())
+        self.assertArray(lo, [-2,-2,-2])
+        self.assertArray(hi, [ 0, 2, 2])
