@@ -1,5 +1,5 @@
 from itaps import iBase, iGeom
-import unittest
+from .. import testhelper as unittest
 import numpy
 
 class TestDiff(unittest.TestCase):
@@ -23,21 +23,21 @@ class TestDiff(unittest.TestCase):
 
         ##### 1 entity, 1 vertex
         coords = self.geom.getEntClosestPt(faces[0], [0,0,0])
-        self.assert_((coords == result[0]).all())
+        self.assertArray(coords, result[0])
         coords = self.geom.getEntClosestPt(faces[0:1], [0,0,0])
-        self.assert_((coords == result[0:1]).all())
+        self.assertArray(coords, result[0:1])
 
         ##### 1 entity, n vertices
         coords = self.geom.getEntClosestPt(faces[0], [[0,0,0]]*6)
-        self.assert_((coords == result[0:1]*6).all())
+        self.assertArray(coords, result[0:1]*6)
 
         ##### n entities, 1 vertex
         coords = self.geom.getEntClosestPt(faces, [0,0,0])
-        self.assert_((coords == result).all())
+        self.assertArray(coords, result)
 
         ##### n entities, n vertices
         coords = self.geom.getEntClosestPt(faces, [[0,0,0]]*6)
-        self.assert_((coords == result).all())
+        self.assertArray(coords, result)
 
     def testNormalXYZ(self):
         self.geom.createBrick(1, 1, 1)
@@ -51,21 +51,21 @@ class TestDiff(unittest.TestCase):
 
         ##### 1 entity, 1 vertex
         coords = self.geom.getEntNormal(faces[0], [0,0,0])
-        self.assert_((coords == result[0]).all())
+        self.assertArray(coords, result[0])
         coords = self.geom.getEntNormal(faces[0:1], [0,0,0])
-        self.assert_((coords == result[0:1]).all())
+        self.assertArray(coords, result[0:1])
 
         ##### 1 entity, n vertices
         coords = self.geom.getEntNormal(faces[0], [[0,0,0]]*6)
-        self.assert_((coords == result[0:1]*6).all())
+        self.assertArray(coords, result[0:1]*6)
 
         ##### n entities, 1 vertex
         coords = self.geom.getEntNormal(faces, [0,0,0])
-        self.assert_((coords == result).all())
+        self.assertArray(coords, result)
 
         ##### n entities, n vertices
         coords = self.geom.getEntNormal(faces, [[0,0,0]]*6)
-        self.assert_((coords == result).all())
+        self.assertArray(coords, result)
 
     def testNormalUV(self):
         self.geom.createBrick(1, 1, 1)
@@ -79,21 +79,21 @@ class TestDiff(unittest.TestCase):
 
         ##### 1 entity, 1 vertex
         coords = self.geom.getEntNormal(faces[0], [0,0], iGeom.Basis.uv)
-        self.assert_((coords == result[0]).all())
+        self.assertArray(coords, result[0])
         coords = self.geom.getEntNormal(faces[0:1], [0,0], iGeom.Basis.uv)
-        self.assert_((coords == result[0:1]).all())
+        self.assertArray(coords, result[0:1])
 
         ##### 1 entity, n vertices
         coords = self.geom.getEntNormal(faces[0], [[0,0]]*6, iGeom.Basis.uv)
-        self.assert_((coords == result[0:1]*6).all())
+        self.assertArray(coords, result[0:1]*6)
 
         ##### n entities, 1 vertex
         coords = self.geom.getEntNormal(faces, [0,0], iGeom.Basis.uv)
-        self.assert_((coords == result).all())
+        self.assertArray(coords, result)
 
         ##### n entities, n vertices
         coords = self.geom.getEntNormal(faces, [[0,0]]*6, iGeom.Basis.uv)
-        self.assert_((coords == result).all())
+        self.assertArray(coords, result)
 
     def testNormalPl(self):
         self.geom.createBrick(2, 2, 2)
@@ -107,26 +107,26 @@ class TestDiff(unittest.TestCase):
 
         ##### 1 entity, 1 vertex
         norm, pts = self.geom.getEntNormalPl(faces[0], [0,0,0])
-        self.assert_((norm == result[0]).all())
-        self.assert_((pts  == result[0]).all())
+        self.assertArray(norm, result[0])
+        self.assertArray(pts,  result[0])
         norm, pts = self.geom.getEntNormalPl(faces[0:1], [0,0,0])
-        self.assert_((norm == result[0:1]).all())
-        self.assert_((pts  == result[0:1]).all())
+        self.assertArray(norm, result[0:1])
+        self.assertArray(pts,  result[0:1])
 
         ##### 1 entity, n vertices
         norm, pts = self.geom.getEntNormalPl(faces[0], [[0,0,0]]*6)
-        self.assert_((norm == result[0:1]*6).all())
-        self.assert_((pts  == result[0:1]*6).all())
+        self.assertArray(norm, result[0:1]*6)
+        self.assertArray(pts,  result[0:1]*6)
 
         ##### n entities, 1 vertex
         norm, pts = self.geom.getEntNormalPl(faces, [0,0,0])
-        self.assert_((norm == result).all())
-        self.assert_((pts  == result).all())
+        self.assertArray(norm, result)
+        self.assertArray(pts,  result)
 
         ##### n entities, n vertices
         norm, pts = self.geom.getEntNormalPl(faces, [[0,0,0]]*6)
-        self.assert_((norm == result).all())
-        self.assert_((pts  == result).all())
+        self.assertArray(norm, result)
+        self.assertArray(pts,  result)
 
     def testTangentXYZ(self):
         self.geom.createBrick(1, 1, 1)
@@ -146,21 +146,21 @@ class TestDiff(unittest.TestCase):
 
         ##### 1 entity, 1 vertex
         coords = self.geom.getEntTangent(edges[0], [0,0,0])
-        self.assert_((coords == result[0]).all())
+        self.assertArray(coords, result[0])
         coords = self.geom.getEntTangent(edges[0:1], [0,0,0])
-        self.assert_((coords == result[0:1]).all())
+        self.assertArray(coords, result[0:1])
 
         ##### 1 entity, n vertices
         coords = self.geom.getEntTangent(edges[0], [[0,0,0]]*12)
-        self.assert_((coords == result[0:1]*12).all())
+        self.assertArray(coords, result[0:1]*12)
 
         ##### n entities, 1 vertex
         coords = self.geom.getEntTangent(edges, [0,0,0])
-        self.assert_((coords == result).all())
+        self.assertArray(coords, result)
 
         ##### n entities, n vertices
         coords = self.geom.getEntTangent(edges, [[0,0,0]]*12)
-        self.assert_((coords == result).all())
+        self.assertArray(coords, result)
 
     def testTangentU(self):
         self.geom.createBrick(1, 1, 1)
@@ -180,21 +180,21 @@ class TestDiff(unittest.TestCase):
 
         ##### 1 entity, 1 vertex
         coords = self.geom.getEntTangent(edges[0], [0], iGeom.Basis.u)
-        self.assert_((coords == result[0]).all())
+        self.assertArray(coords, result[0])
         coords = self.geom.getEntTangent(edges[0:1], [0], iGeom.Basis.u)
-        self.assert_((coords == result[0:1]).all())
+        self.assertArray(coords, result[0:1])
 
         ##### 1 entity, n vertices
         coords = self.geom.getEntTangent(edges[0], [[0]]*12, iGeom.Basis.u)
-        self.assert_((coords == result[0:1]*12).all())
+        self.assertArray(coords, result[0:1]*12)
 
         ##### n entities, 1 vertex
         coords = self.geom.getEntTangent(edges, [0], iGeom.Basis.u)
-        self.assert_((coords == result).all())
+        self.assertArray(coords, result)
 
         ##### n entities, n vertices
         coords = self.geom.getEntTangent(edges, [[0]]*12, iGeom.Basis.u)
-        self.assert_((coords == result).all())
+        self.assertArray(coords, result)
 
     def testCurvatureXYZ(self):
         self.geom.createCylinder(1,1,1)
@@ -203,57 +203,57 @@ class TestDiff(unittest.TestCase):
 
         ##### edges; 1 entity, 1 vertex
         coords = self.geom.getEntCurvature(edges[0], [0,1,0])
-        self.assert_((coords == [0,-1,0]).all())
+        self.assertArray(coords, [0,-1,0])
         coords = self.geom.getEntCurvature(edges[0], [0,1,0],
                                            type=iBase.Type.edge)
-        self.assert_((coords == [0,-1,0]).all())
+        self.assertArray(coords, [0,-1,0])
         coords = self.geom.getEntCurvature(edges[0:1], [0,1,0])
-        self.assert_((coords == [[0,-1,0]]).all())
+        self.assertArray(coords, [[0,-1,0]])
 
         ##### edges; 1 entity, n vertices
         coords = self.geom.getEntCurvature(edges[0], [[0,1,0],[0,-1,0]])
-        self.assert_((coords == [[0,-1,0],[0,1,0]]).all())
+        self.assertArray(coords, [[0,-1,0],[0,1,0]])
 
         ##### edges; n entities, 1 vertex
         coords = self.geom.getEntCurvature(edges, [0,1,0])
-        self.assert_((coords == [[0,-1,0],[0,-1,0]]).all())
+        self.assertArray(coords, [[0,-1,0],[0,-1,0]])
 
         ##### edges; n entities, n vertices
         coords = self.geom.getEntCurvature(edges, [[0,1,0],[0,-1,0]])
-        self.assert_((coords == [[0,-1,0],[0,1,0]]).all())
+        self.assertArray(coords, [[0,-1,0],[0,1,0]])
 
         ##### faces; 1 entity, 1 vertex
         coords = self.geom.getEntCurvature(faces[0], [0,1,0])
         self.assertEqual(len(coords), 2)
-        self.assert_((coords[0] == [0,0,0]).all())
-        self.assert_((coords[1] == [1,0,0]).all())
+        self.assertArray(coords[0], [0,0,0])
+        self.assertArray(coords[1], [1,0,0])
         coords = self.geom.getEntCurvature(faces[0], [0,1,0],
                                            type=iBase.Type.face)
         self.assertEqual(len(coords), 2)
-        self.assert_((coords[0] == [0,0,0]).all())
-        self.assert_((coords[1] == [1,0,0]).all())
+        self.assertArray(coords[0], [0,0,0])
+        self.assertArray(coords[1], [1,0,0])
         coords = self.geom.getEntCurvature(faces[0:1], [0,1,0])
         self.assertEqual(len(coords), 2)
-        self.assert_((coords[0] == [0,0,0]).all())
-        self.assert_((coords[1] == [1,0,0]).all())
+        self.assertArray(coords[0][0], [0,0,0])
+        self.assertArray(coords[1][0], [1,0,0])
 
         ##### faces; 1 entity, n vertices
         coords = self.geom.getEntCurvature(faces[0], [[0,1,0],[0,-1,0]])
         self.assertEqual(len(coords), 2)
-        self.assert_((coords[0] == [[0,0,0], [ 0,0,0]]).all())
-        self.assert_((coords[1] == [[1,0,0], [-1,0,0]]).all())
+        self.assertArray(coords[0], [[0,0,0], [ 0,0,0]])
+        self.assertArray(coords[1], [[1,0,0], [-1,0,0]])
 
         ##### faces; n entities, 1 vertex
         coords = self.geom.getEntCurvature(faces, [0,1,0])
         self.assertEqual(len(coords), 2)
-        self.assert_((coords[0] == [[0,0,0], [0,0,0], [0,0,0]]).all())
-        self.assert_((coords[1] == [[1,0,0], [0,0,0], [0,0,0]]).all())
+        self.assertArray(coords[0], [[0,0,0], [0,0,0], [0,0,0]])
+        self.assertArray(coords[1], [[1,0,0], [0,0,0], [0,0,0]])
 
         ##### faces; n entities, n vertices
         coords = self.geom.getEntCurvature(faces, [[0,1,0]]*3)
         self.assertEqual(len(coords), 2)
-        self.assert_((coords[0] == [[0,0,0], [0,0,0], [0,0,0]]).all())
-        self.assert_((coords[1] == [[1,0,0], [0,0,0], [0,0,0]]).all())
+        self.assertArray(coords[0], [[0,0,0], [0,0,0], [0,0,0]])
+        self.assertArray(coords[1], [[1,0,0], [0,0,0], [0,0,0]])
 
     def testCurvatureUV(self):
         self.geom.createCylinder(1,1,1)
@@ -262,36 +262,36 @@ class TestDiff(unittest.TestCase):
         ##### 1 entity, 1 vertex
         coords = self.geom.getEntCurvature(faces[0], [0,0], iGeom.Basis.uv)
         self.assertEqual(len(coords), 2)
-        self.assert_((coords[0] == [ 0, 0, 0]).all())
-        self.assert_((coords[1] == [ 0,-1, 0]).all())
+        self.assertArray(coords[0], [ 0, 0, 0])
+        self.assertArray(coords[1], [ 0,-1, 0])
         coords = self.geom.getEntCurvature(faces[0], [0,0], iGeom.Basis.uv,
                                            iBase.Type.face)
         self.assertEqual(len(coords), 2)
-        self.assert_((coords[0] == [ 0, 0, 0]).all())
-        self.assert_((coords[1] == [ 0,-1, 0]).all())
+        self.assertArray(coords[0], [ 0, 0, 0])
+        self.assertArray(coords[1], [ 0,-1, 0])
         coords = self.geom.getEntCurvature(faces[0:1], [0,0], iGeom.Basis.uv)
         self.assertEqual(len(coords), 2)
-        self.assert_((coords[0] == [ 0, 0, 0]).all())
-        self.assert_((coords[1] == [ 0,-1, 0]).all())
+        self.assertArray(coords[0][0], [ 0, 0, 0])
+        self.assertArray(coords[1][0], [ 0,-1, 0])
 
         ##### 1 entity, n vertices
         coords = self.geom.getEntCurvature(faces[0], [[0,0],[0,0]],
                                            iGeom.Basis.uv)
         self.assertEqual(len(coords), 2)
-        self.assert_((coords[0] == [[ 0, 0, 0], [ 0, 0, 0]]).all())
-        self.assert_((coords[1] == [[ 0,-1, 0], [ 0,-1, 0]]).all())
+        self.assertArray(coords[0], [[ 0, 0, 0], [ 0, 0, 0]])
+        self.assertArray(coords[1], [[ 0,-1, 0], [ 0,-1, 0]])
 
         ##### n entities, 1 vertex
         coords = self.geom.getEntCurvature(faces, [0,0], iGeom.Basis.uv)
         self.assertEqual(len(coords), 2)
-        self.assert_((coords[0] == [[ 0, 0, 0], [ 0, 0, 0], [ 0, 0, 0]]).all())
-        self.assert_((coords[1] == [[ 0,-1, 0], [ 0, 0, 0], [ 0, 0, 0]]).all())
+        self.assertArray(coords[0], [[ 0, 0, 0], [ 0, 0, 0], [ 0, 0, 0]])
+        self.assertArray(coords[1], [[ 0,-1, 0], [ 0, 0, 0], [ 0, 0, 0]])
 
         ##### n entities, n vertices
         coords = self.geom.getEntCurvature(faces, [[0,0]]*3, iGeom.Basis.uv)
         self.assertEqual(len(coords), 2)
-        self.assert_((coords[0] == [[ 0, 0, 0], [ 0, 0, 0], [ 0, 0, 0]]).all())
-        self.assert_((coords[1] == [[ 0,-1, 0], [ 0, 0, 0], [ 0, 0, 0]]).all())
+        self.assertArray(coords[0], [[ 0, 0, 0], [ 0, 0, 0], [ 0, 0, 0]])
+        self.assertArray(coords[1], [[ 0,-1, 0], [ 0, 0, 0], [ 0, 0, 0]])
 
     def testEval(self):
         self.geom.createCylinder(2,1,1)
@@ -303,32 +303,32 @@ class TestDiff(unittest.TestCase):
                                [  1,  0,  0],
                                [  0, -1,  0] ])
         coords = self.geom.getEntEval(edges[0], [0,1,0])
-        self.assert_((coords == result).all())
+        self.assertArray(coords, result)
         coords = self.geom.getEntEval(edges[0:1], [0,1,0])
-        self.assert_((coords == result.reshape(3,1,3)).all())
+        self.assertArray(coords, result.reshape(3,1,3))
         coords = self.geom.getEntEval(edges[0], [0,1,0], iBase.Type.edge)
-        self.assert_((coords == result).all())
+        self.assertArray(coords, result)
         coords = self.geom.getEntEval(edges[0:1], [0,1,0], iBase.Type.edge)
-        self.assert_((coords == result.reshape(3,1,3)).all())
+        self.assertArray(coords, result.reshape(3,1,3))
 
         ##### edges; 1 entity, n vertices
         result = numpy.array([ [[  0,  1, -1], [  0, -1, -1]],
                                [[  1,  0,  0], [ -1,  0,  0]],
                                [[  0, -1,  0], [  0,  1,  0]] ])
         coords = self.geom.getEntEval(edges[0], [[0,1,0], [0,-1,0]])
-        self.assert_((coords == result).all())
+        self.assertArray(coords, result)
         coords = self.geom.getEntEval(edges[0], [[0,1,0], [0,-1,0]],
                                       iBase.Type.edge)
-        self.assert_((coords == result).all())
+        self.assertArray(coords, result)
 
         ##### edges; n entities, 1 vertex
         result = numpy.array([ [[  0,  1, -1], [  0,  1,  1]],
                                [[  1,  0,  0], [ -1,  0,  0]],
                                [[  0, -1,  0], [  0, -1,  0]] ])
         coords = self.geom.getEntEval(edges, [0,1,0])
-        self.assert_((coords == result).all())
+        self.assertArray(coords, result)
         coords = self.geom.getEntEval(edges, [0,1,0], iBase.Type.edge)
-        self.assert_((coords == result).all())
+        self.assertArray(coords, result)
 
         ##### edges; n entities, n vertices
         result = numpy.array([ [[  0,  1, -1], [  0, -1,  1]],
@@ -336,10 +336,10 @@ class TestDiff(unittest.TestCase):
                                [[  0, -1,  0], [  0,  1,  0]] ])
         coords = self.geom.getEntEval(edges, [[0,1,0],[0,-1,0]],
                                       iBase.Type.edge)
-        self.assert_((coords == result).all())
+        self.assertArray(coords, result)
         coords = self.geom.getEntEval(edges, [[0,1,0],[0,-1,0]],
                                       iBase.Type.edge)
-        self.assert_((coords == result).all())
+        self.assertArray(coords, result)
 
         ##### faces; 1 entity, 1 vertex
         result = numpy.array([ [ 0,  1,  0,],
@@ -347,13 +347,13 @@ class TestDiff(unittest.TestCase):
                                [ 0,  0,  0,],
                                [ 1,  0,  0,] ])
         coords = self.geom.getEntEval(faces[0], [0,1,0])
-        self.assert_((coords == result).all())
+        self.assertArray(coords, result)
         coords = self.geom.getEntEval(faces[0:1], [0,1,0])
-        self.assert_((coords == result.reshape(4,1,3)).all())
+        self.assertArray(coords, result.reshape(4,1,3))
         coords = self.geom.getEntEval(faces[0], [0,1,0], iBase.Type.face)
-        self.assert_((coords == result).all())
+        self.assertArray(coords, result)
         coords = self.geom.getEntEval(faces[0:1], [0,1,0], iBase.Type.face)
-        self.assert_((coords == result.reshape(4,1,3)).all())
+        self.assertArray(coords, result.reshape(4,1,3))
 
         ##### faces; 1 entity, n vertices
         result = numpy.array([ [[ 0,  1,  0,], [ 0, -1,  0,]],
@@ -362,10 +362,10 @@ class TestDiff(unittest.TestCase):
                                [[ 1,  0,  0,], [-1,  0,  0,]] ])
 
         coords = self.geom.getEntEval(faces[0], [[0,1,0],[0,-1,0]])
-        self.assert_((coords == result).all())
+        self.assertArray(coords, result)
         coords = self.geom.getEntEval(faces[0], [[0,1,0],[0,-1,0]],
                                       iBase.Type.face)
-        self.assert_((coords == result).all())
+        self.assertArray(coords, result)
 
         ##### faces; n entities, 1 vertex
         result = numpy.array([ [[ 0,  1,  0,], [ 0,  1, -1,], [ 0,  1,  1,]],
@@ -373,9 +373,9 @@ class TestDiff(unittest.TestCase):
                                [[ 0,  0,  0,], [-0,  0,  0,], [ 0,  0,  0,]],
                                [[ 1,  0,  0,], [ 0,  0,  0,], [ 0,  0,  0,]] ])
         coords = self.geom.getEntEval(faces, [0,1,0])
-        self.assert_((coords == result).all())
+        self.assertArray(coords, result)
         coords = self.geom.getEntEval(faces, [0,1,0], iBase.Type.face)
-        self.assert_((coords == result).all())
+        self.assertArray(coords, result)
 
         ##### faces; n entities, n vertices
         result = numpy.array([ [[ 0,  1,  0,], [ 0,  1, -1,], [ 0,  1,  1,]],
@@ -383,21 +383,21 @@ class TestDiff(unittest.TestCase):
                                [[ 0,  0,  0,], [-0,  0,  0,], [ 0,  0,  0,]],
                                [[ 1,  0,  0,], [ 0,  0,  0,], [ 0,  0,  0,]] ])
         coords = self.geom.getEntEval(faces, [[0,1,0]]*3)
-        self.assert_((coords == result).all())
+        self.assertArray(coords, result)
         coords = self.geom.getEntEval(faces, [[0,1,0]]*3, iBase.Type.face)
-        self.assert_((coords == result).all())
+        self.assertArray(coords, result)
 
     def testClassification(self):
         self.geom.createBrick(4, 4, 4)
         faces = self.geom.getEntities(iBase.Type.face)
 
         found = self.geom.getPtClass([1, 1, 2])
-        self.assert_(found in faces)
+        self.assertTrue(found in faces)
         self.assertRaises(iBase.ITAPSError, self.geom.getPtClass, [2, 2, 4])
 
         found = self.geom.getPtClass([[1, 1, 2], [1, 2, 1], [2, 1, 1]])
         for i in found:
-            self.assert_(i in faces)
+            self.assertTrue(i in faces)
         
         self.assertRaises(iBase.ITAPSError, self.geom.getPtClass,
                           [[2, 2, 4], [1, 2, 1], [2, 1, 1]])
@@ -411,19 +411,19 @@ class TestDiff(unittest.TestCase):
         sense = self.geom.getEntNormalSense(faces[0], region)
         self.assertEqual(sense, 1)
         sense = self.geom.getEntNormalSense(faces[0:1], [region])
-        self.assert_((sense == [1]).all())
+        self.assertArray(sense, [1])
 
         ##### 1 face, n regions
         sense = self.geom.getEntNormalSense(faces[0], [region]*6)
-        self.assert_((sense == [1]*6).all())
+        self.assertArray(sense, [1]*6)
 
         ##### n faces, 1 region
         sense = self.geom.getEntNormalSense(faces, region)
-        self.assert_((sense == [1]*6).all())
+        self.assertArray(sense, [1]*6)
 
         ##### n faces, n regions
         sense = self.geom.getEntNormalSense(faces, [region]*6)
-        self.assert_((sense == [1]*6).all())
+        self.assertArray(sense, [1]*6)
 
     def testEgFcSense(self):
         self.geom.createBrick(2, 2, 2)
@@ -434,20 +434,20 @@ class TestDiff(unittest.TestCase):
         sense = self.geom.getEgFcSense(edges[0,0], faces[0])
         self.assertEqual(sense, 1)
         sense = self.geom.getEgFcSense([edges[0,1]], faces[0:1])
-        self.assert_((sense == [1]).all())
+        self.assertArray(sense, [1])
 
         ##### 1 edge, n faces
         sense = self.geom.getEgFcSense(edges[0,0], [faces[0]]*6)
-        self.assert_((sense == [1]*6).all())
+        self.assertArray(sense, [1]*6)
 
         ##### n edges, 1 face
         sense = self.geom.getEgFcSense(edges[0], faces[0])
-        self.assert_((sense == [1]*4).all())
+        self.assertArray(sense, [1]*4)
 
         ##### n edges, n faces
         first_edges = [ edges[i,0] for i in range(len(edges)) ]
         sense = self.geom.getEgFcSense(first_edges, faces)
-        self.assert_((sense == [1]*6).all())
+        self.assertArray(sense, [1]*6)
 
     def testEgVtxSense(self):
         self.geom.createBrick(2, 2, 2)
@@ -461,37 +461,37 @@ class TestDiff(unittest.TestCase):
         sense = self.geom.getEgVtxSense(edges[0], pre[0], post[0])
         self.assertEqual(sense, 1)
         sense = self.geom.getEgVtxSense(edges[0:1], pre[0:1], post[0:1])
-        self.assert_((sense == [1]).all())
+        self.assertArray(sense, [1])
 
         ##### 1 edge, 1 vertex, n vertices
         sense = self.geom.getEgVtxSense(edges[0], pre[0], post[0:1]*2)
-        self.assert_((sense == [1, 1]).all())
+        self.assertArray(sense, [1, 1])
 
         ##### 1 edge, n vertices, 1 vertex
         sense = self.geom.getEgVtxSense(edges[0], pre[0:1]*2, post[0])
-        self.assert_((sense == [1, 1]).all())
+        self.assertArray(sense, [1, 1])
 
         ##### 1 edge, n vertices, n vertices
         sense = self.geom.getEgVtxSense(edges[0], verts[0], verts[0][::-1])
-        self.assert_((sense == [1, -1]).all())
+        self.assertArray(sense, [1, -1])
 
         twice = edges[0:1].tolist()*2
 
         ##### n edges, 1 vertex, 1 vertex
         sense = self.geom.getEgVtxSense(twice, pre[0], post[0])
-        self.assert_((sense == [1, 1]).all())
+        self.assertArray(sense, [1, 1])
 
         ##### n edges, 1 vertex, n vertices
         sense = self.geom.getEgVtxSense(twice, pre[0], post[0:1]*2)
-        self.assert_((sense == [1, 1]).all())
+        self.assertArray(sense, [1, 1])
 
         ##### n edges, n vertices, 1 vertex
         sense = self.geom.getEgVtxSense(twice, pre[0:1]*2, post[0])
-        self.assert_((sense == [1, 1]).all())
+        self.assertArray(sense, [1, 1])
 
         ##### n edges, n vertices, n vertices
         sense = self.geom.getEgVtxSense(edges, pre, post)
-        self.assert_((sense == [1]*12).all())
+        self.assertArray(sense, [1]*12)
 
     def testFcDegenerate(self):
         self.geom.createBrick(2, 2, 2)
@@ -506,9 +506,8 @@ class TestDiff(unittest.TestCase):
     def testRayIntersect(self):
         self.geom.createSphere(1)
 
-        # TODO: this always causes a floating point exception for some reason
-        self.fail("getPtRayIntersect will crash, ignoring it")
-        # print self.geom.getPtRayIntersect([5,0,0], [1,0,0])
+        ents, isect, param = self.geom.getPtRayIntersect([0,0,0], [1,0,0])
+        # TODO: finish this
 
     def test1stDeriv(self):
         self.geom.createBrick(1, 1, 1)
@@ -529,18 +528,18 @@ class TestDiff(unittest.TestCase):
               [ 0,  1,  0] ]
 
         deriv = self.geom.getEnt1stDerivative(faces[0], [0,0])
-        self.assert_((deriv[0] == u[0]).all())
-        self.assert_((deriv[1] == v[0]).all())
+        self.assertArray(deriv[0], u[0])
+        self.assertArray(deriv[1], v[0])
 
         deriv = self.geom.getEnt1stDerivative(faces[0:1], [[0,0]])
-        self.assert_((deriv.offsets == offsets[0:2]).all())
-        self.assert_((deriv.data[0] == u[0:1]).all())
-        self.assert_((deriv.data[1] == v[0:1]).all())
+        self.assertArray(deriv.offsets, offsets[0:2])
+        self.assertArray(deriv.data[0], u[0:1])
+        self.assertArray(deriv.data[1], v[0:1])
 
         deriv = self.geom.getEnt1stDerivative(faces, [[0,0]]*6)
-        self.assert_((deriv.offsets == offsets).all())
-        self.assert_((deriv.data[0] == u).all())
-        self.assert_((deriv.data[1] == v).all())
+        self.assertArray(deriv.offsets, offsets)
+        self.assertArray(deriv.data[0], u)
+        self.assertArray(deriv.data[1], v)
 
     def test2ndDeriv(self):
         self.geom.createBrick(1, 1, 1)
@@ -553,7 +552,3 @@ class TestDiff(unittest.TestCase):
                                               Stg.interleaved)
 
         deriv = self.geom.getEnt2ndDerivative(faces, [[0,0]]*6)
-
-
-if __name__ == '__main__':
-    unittest.main()
