@@ -325,13 +325,13 @@ class TestTags(unittest.TestCase):
         self.dtag[self.ent] = 42
 
         tags = self.geom.getAllTags(self.ent)
-        self.assert_(self.itag in tags)
-        self.assert_(self.dtag in tags)
+        self.assertTrue(self.itag in tags)
+        self.assertTrue(self.dtag in tags)
 
     def testSetGetAll(self):
         self.itag[self.set] = 42
         self.dtag[self.set] = 42
 
         tags = self.geom.getAllTags(self.set)
-        self.assert_(self.itag in tags)
-        self.assert_(self.dtag in tags)
+        self.assertTrue(self.itag in tags)
+        self.assertTrue(self.dtag in tags)
