@@ -1,6 +1,6 @@
 from itaps import iBase, iMesh
-import unittest
-Topo = iMesh.Topology
+from .. import testhelper as unittest
+Topo = iMesh.Topology # shorthand
 
 class TestIter(unittest.TestCase):
     def setUp(self):
@@ -59,6 +59,3 @@ class TestIter(unittest.TestCase):
         self.helpSingle(iterator)
         iterator.reset()
         self.helpSingle(iterator)
-
-if __name__ == '__main__':
-    unittest.main()
