@@ -16,8 +16,8 @@ class TestBasic(unittest.TestCase):
                                    self.geom, iRel.Type.entity)
 
         self.assertEqual(pair.instance, self.rel)
-        self.assertEqual(pair.first,    self.mesh)
-        self.assertEqual(pair.second,   self.geom)
+        self.assertEqual(pair.left.instance,  self.mesh)
+        self.assertEqual(pair.right.instance, self.geom)
 
         self.rel.destroyPair(pair)
 
@@ -28,6 +28,19 @@ class TestBasic(unittest.TestCase):
     def testPair(self):
         pair = self.rel.createPair(self.mesh, iRel.Type.entity,
                                    self.geom, iRel.Type.entity)
+
+        self.assertEqual(self.rel.findPairs(self.mesh), [pair])
+        self.assertEqual(self.rel.findPairs(self.geom), [pair])
+
+        self.rel.destroyPair(pair)
+        self.assertEqual(len(self.rel.findPairs(self.mesh)), 0)
+        self.assertEqual(len(self.rel.findPairs(self.geom)), 0)
+
+    def testPairAlt(self):
+        pair = self.rel.createPair(
+            self.mesh, iRel.Type.entity, iRel.Status.active,
+            self.geom, iRel.Type.entity, iRel.Status.active)
+
         self.assertEqual(self.rel.findPairs(self.mesh), [pair])
         self.assertEqual(self.rel.findPairs(self.geom), [pair])
 
